Coverage for .tox/p313/lib/python3.13/site-packages/scicom/interface.py: 0%

1"""Solara interface for all simulations."""

2 import os

3

4 import solara

5

6 from scicom.historicalletters.interface import page as historical_letters_page

7

8

9@solara.component

10 def Home() -> str:

11 return solara.Markdown(r"""

12# Historical Letters Simulation

13

14## The model

15 A letter sending model with historically informed initial positions to reconstruct communication and archiving processes in the Republic of Letters, the 15th to 17th century form of scholarship.

16

17## The audience

18 The model is aimed at historians, willing to formalize historical assumptions about the letter sending process itself and allows in principle to set heterogeneous social roles, e.g. to evaluate the role of gender or social status in the formation of letter exchange networks. The model furthermore includes a pruning process to simulate the loss of letters to critically asses the role of biases e.g. in relation to gender, geographical regions, or power structures, in the creation of empirical letter archives.

19

20## What are the essentials?

21 Each agent has an initial random topic vector, expressed as a RGB value. The initial positions of the agents are based on a weighted random draw based on data from [2]. In each step, agents generate two neighbourhoods for sending letters and potential targets to move towards. The probability to send letters is a self-reinforcing process. After each sending the internal topic of the receiver is updated as a movement in abstract space by a random amount towards the letters topic.

22

23## What is the output?

24 All send letters are tracked in a ledger which is the basis for further research on archival processes by performing random or targeted deletion of records. Changes in network measures are compared to results from empirical letter networks to find likely biases underlying the archive creation. The deletion can be selected as part of the agent-based simulation. In this case a range of network measures is calculated on copies of the ledger where letters have been deleted by different deletion strategies.

25

26## Where can I find more information?

27

28> Malte Vogl, Bernardo Buarque, Jascha Merijn Schmitz, Aleksandra Kaye (2024, May 24).

29>“Historical Letters” (Version 1.1.0).

30>CoMSES Computational Model Library.

31>URL: Retrieved from: https://doi.org/10.25937/x2ve-rc93

32

33""")

34

35

36@solara.component

37 def historicalletters():

38 return historical_letters_page

39

40@solara.component

41 def lesson():

42 with open(os.path.join(os.path.dirname(__file__), "simulations.md")) as file:

43 return solara.Markdown("\n".join(file.readlines()))

44

45 routes = [

46 solara.Route(path="/", component=Home, label="The model"),

47 solara.Route(

48 path="historicalletters", component=historicalletters, label="Historical Letters",

49 ),

50 solara.Route(path="lesson", component=lesson, label="Background"),

51]